/*
	SofK Style for KDE 3+
	
		Copyright (C) 2006 xactive <xactive@o2.pl>
	
	Based on Serenity style:
	
		Copyright (C) 2006 Remi Villatel <maxilys@tele2.fr>
		
	This library is free software; you can redistribute it and/or 
	modify it under the terms of the GNU Library General Public 
	License version 2 as published by the Free Software Foundation.
	
	This library is distributed in the hope that it will be useful, 
	but WITHOUT ANY WARRANTY; without even the implied warranty of 
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
	Library General Public License for more details.
	
	You should have received a copy of the GNU Library General Public 
	License along with this library. (See the file COPYING.) If not, 
	write to:
	The Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
	Boston, MA 02111-1307, USA.
*/

#include <qapplication.h>
#include <qcheckbox.h>
#include <qcolor.h>
#include <qcombobox.h>
#include <qhbox.h>
#include <qvbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qsettings.h>
#include <qslider.h>
#include <qtabwidget.h>
#include <qvgroupbox.h>

#include <kglobal.h>
#include <klocale.h>
#include <kcolorbutton.h>

#include "sofkconf.h"

extern "C"
{
	QWidget* allocate_kstyle_config(QWidget* parent)
	{
		KGlobal::locale()->insertCatalogue("kstyle_sofk_config");
		return new sofkStyleConfig(parent);
	}
}

sofkStyleConfig::sofkStyleConfig(QWidget* parent): QWidget(parent)
{
	QVBoxLayout* layout = new QVBoxLayout(this, 0, 0);
	QGridLayout* tabLayout = new QGridLayout(this, 2, 1, 10);

	KGlobal::locale()->insertCatalogue("kstyle_sofk_config");

	///Init tabs
	QTabWidget *tabWidget = new QTabWidget(this);
	layout->addWidget(tabWidget);

	///Init tab 1 
	QWidget *page1 = new QWidget(tabWidget);
        layout = new QVBoxLayout(page1);
	
	tabWidget->insertTab(page1, i18n("Configuration"));
	
	layout->addLayout(tabLayout);	

	/// General group
	QVGroupBox* generalGrp = new QVGroupBox(i18n("General"), page1);

	drawTriangularExpander = new QCheckBox(i18n("Triangular tree expander"), generalGrp);
	drawFocusRect = new QCheckBox(i18n("Draw focus rectangles"), generalGrp);
	drawToolBarHandle = new QCheckBox(i18n("Draw toolbar handles"), generalGrp);
	drawToolBarSeparator = new QCheckBox(i18n("Draw toolbar separators"), generalGrp);
	//
	QHBox* hbox11 = new QHBox(generalGrp);
	QLabel* scrollBarStyleLabel;
	scrollBarStyleLabel = new QLabel(i18n("Scrollbar style: "), hbox11);
	scrollBarStyle = new QComboBox(i18n("Scrollbar style"), hbox11);
	scrollBarStyle->setEditable(false);
	scrollBarStyle->insertItem("Windows");
	scrollBarStyle->insertItem("Platinum");
	scrollBarStyle->insertItem("KDE");
	scrollBarStyle->insertItem("NeXT");
	scrollBarStyle->insertItem("Arrowless");
	scrollBarStyleLabel->setBuddy(scrollBarStyle);
	//
	centerTabs = new QCheckBox(i18n("Center tabs"), generalGrp);
	//
	QHBox* hbox12 = new QHBox(generalGrp);
	QLabel* tabWarnStyleLabel;
	tabWarnStyleLabel = new QLabel(i18n("Tab warnings: "), hbox12);
	tabWarnStyle = new QComboBox(i18n("Tab warnings"), hbox12);
	tabWarnStyle->setEditable(false);
	tabWarnStyle->insertItem("Deactivated");
	tabWarnStyle->insertItem("Bold text");
	tabWarnStyle->insertItem("Italic text");
	tabWarnStyle->insertItem("App. default");
	tabWarnStyleLabel->setBuddy(tabWarnStyle);
	//
	QLabel* submenuSpeedLabel;
	submenuSpeedLabel = new QLabel(i18n("Popup sub-menus delay: "), generalGrp);
	submenuSpeed = new QSlider(-8, 8, 1, 0, Qt::Horizontal, generalGrp);
	submenuSpeed->setTickmarks(QSlider::Below);
	submenuSpeed->setTickInterval(4);
	submenuSpeedLabel->setBuddy(submenuSpeed);
	QHBox* tickBox = new QHBox(generalGrp);
	QLabel* fastLabel;
	QLabel* regularLabel;
	QLabel* slowLabel;
	fastLabel = new QLabel(i18n("fast"), tickBox);
	regularLabel = new QLabel(i18n("standard"), tickBox);
	slowLabel = new QLabel(i18n("slow"), tickBox);
	if ( QApplication::reverseLayout() )
	{
		fastLabel->setAlignment(AlignRight);
		slowLabel->setAlignment(AlignLeft);
	}
	else
	{
		fastLabel->setAlignment(AlignLeft);
		slowLabel->setAlignment(AlignRight);
	}
	regularLabel->setAlignment(AlignHCenter);

	tabLayout->addWidget(generalGrp, 0, 0, 0);

	/// sofk group
	QVGroupBox *softGrp = new QVGroupBox("sofk", page1);
	
	QHBox* hbox21 = new QHBox(softGrp);
	QLabel* gradientStyleLabel;
	gradientStyleLabel = new QLabel(i18n("Gradient style: "), hbox21);
	gradientStyle = new QComboBox(i18n("Gradient style"), hbox21);
	gradientStyle->setEditable(false);
	gradientStyle->insertItem("Regular");
	gradientStyle->insertItem("Flat");
	gradientStyle->insertItem("Soft");
	gradientStyle->insertItem("Hard");
	gradientStyleLabel->setBuddy(gradientStyle);
	//
	alternateSinking = new QCheckBox(i18n("Use alternate sunken effect"), softGrp);
	customOverHighlightColor = new QCheckBox(i18n("Custom mouseover highlight color:"), softGrp);
	QHBox *hbox3 = new QHBox(softGrp);
	hbox3->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
	overHighlightColor = new KColorButton(hbox3);
	//mouseOver = new QCheckBox(i18n("Mouseover checkmark/radiobutton label"), softGrp);
	//
	QHBox* hbox22 = new QHBox(softGrp);
	QLabel* progressBarPatternLabel;
	progressBarPatternLabel = new QLabel(i18n("Progress Bar Pattern: "), hbox22);
	progressBarPattern = new QComboBox(i18n("Gradient style"), hbox22);
	progressBarPattern->setEditable(false);
	progressBarPattern->insertItem("Arrows");
	progressBarPattern->insertItem("Candy Bar");
	progressBarPattern->insertItem("Checker");
	progressBarPattern->insertItem("Waves");
	progressBarPatternLabel->setBuddy(progressBarPattern);
	//
	flatProgressBar = new QCheckBox(i18n("Flat progress bars"), softGrp);
	animateProgressBar = new QCheckBox(i18n("Animate progress bars"), softGrp);
	menuGroove = new QCheckBox(i18n("Paint menu groove"), softGrp);
	drawsoftGroupBox = new QCheckBox(i18n("Draw soft groupboxes"), softGrp);
	//
	QHBox* hbox23 = new QHBox(softGrp);
	QLabel* tabStyleLabel;
	tabStyleLabel = new QLabel(i18n("Active tab style: "), hbox23);
	tabStyle = new QComboBox(i18n("Tab style"), hbox23);
	tabStyle->setEditable(false);
	tabStyle->insertItem("Highlighted button");
	tabStyle->insertItem("soft button");
	tabStyle->insertItem("Highlighted gradient");
	tabStyle->insertItem("soft gradient");
	tabStyle->insertItem("Flat");
	tabStyleLabel->setBuddy(tabStyle);
	//
	drawSolidSeparator = new QCheckBox(i18n("Draw solid separators"), softGrp);

	tabLayout->addWidget(softGrp, 0, 1, 0);	

	/// Init tab 2
	QWidget *page2 = new QWidget(tabWidget);
	QLabel* sofkLabel;
	QLabel* lipstikLabel;
	QLabel* alsoLabel;
	QLabel* aLabel1;
	QLabel* aLabel2;
	QLabel* aLabel3;
	QLabel* aLabel4;
	QLabel* aLabel5;
	QLabel* aLabel6;
	QLabel* aLabel7;
	
        layout = new QVBoxLayout(page2, 8, -1);
	
	tabWidget->insertTab(page2, i18n("About"));
	
	sofkLabel = new QLabel("<b>SofK 0.0.3</b><br>Copyright 2006 (C) xactive &lt;xactive@o2.pl&gt;", 
					page2);
	sofkLabel->setMargin(5);
	sofkLabel->setAlignment(AlignHCenter);
	sofkLabel->setFrameStyle(QFrame::Box | QFrame::Sunken);
	lipstikLabel = new QLabel(i18n("Based on Serenity sources"), page2);
	alsoLabel = new QLabel(i18n("Also inspired by:"), page2);
	aLabel1 = new QLabel(i18n("-- The sources of several styles, in no particular order"), 
				page2);
	aLabel2 = new QLabel(i18n("      Plastik, DotNet, QtCurve, HighContrast, Keramik, etc."), 
				page2);
	aLabel3 = new QLabel(i18n("      Thanks to their author."), 
				page2);
	aLabel4 = new QLabel(i18n("-- The sources of KDE 3.5 (my bedside book)."), page2);
	aLabel5 = new QLabel(i18n("      Thanks to the KDE developers."), page2);
	aLabel6 = new QLabel(i18n("-- The sources of Qt 3 (another good bedside book)."), 
				page2);
	aLabel7 = new QLabel(i18n("      Thanks to the Trolls who made all this possible."), 
				page2);

	layout->add(sofkLabel);
	layout->addSpacing(4);
	layout->add(lipstikLabel);
//	layout->addSpacing(1);
//	layout->add(alsoLabel);
//	layout->addSpacing(1);
//	layout->add(aLabel1);
//	layout->add(aLabel2);
	layout->add(aLabel3);
//	layout->addSpacing(1);
//	layout->add(aLabel4);
//	layout->add(aLabel5);
//	layout->addSpacing(5);
//	layout->add(aLabel6);
//	layout->add(aLabel7);
//	layout->addSpacing(10);

	/// Read config and populate!
	QSettings s;

	origDrawTriangularExpander = s.readBoolEntry("/sofkstyle/Settings/drawTriangularExpander", true);
	drawTriangularExpander->setChecked(origDrawTriangularExpander);
	origDrawFocusRect = s.readBoolEntry("/sofkstyle/Settings/drawFocusRect", true);
	drawFocusRect->setChecked(origDrawFocusRect);
	origDrawToolBarHandle = s.readBoolEntry("/sofkstyle/Settings/drawToolBarHandle", false);
	drawToolBarHandle->setChecked(origDrawToolBarHandle);
	origDrawToolBarSeparator = s.readBoolEntry("/sofkstyle/Settings/drawToolBarSeparator", false);
	drawToolBarSeparator->setChecked(origDrawToolBarSeparator);
	origScrollBarStyle = s.readEntry("/sofkstyle/Settings/scrollBarStyle", "ThreeButtonScrollBar");
	scrollBarStyle->setCurrentItem(scrollBarItem(origScrollBarStyle));
	origCenterTabs = s.readBoolEntry("/sofkstyle/Settings/centerTabs", false);
	centerTabs->setChecked(origCenterTabs);
	origTabWarnStyle = s.readEntry("/sofkstyle/Settings/tabWarningStyle", "Deactivated");
	tabWarnStyle->setCurrentItem(tabWarnItem(origTabWarnStyle));
	origSubmenuSpeed = s.readNumEntry("/sofkstyle/Settings/submenuSpeed", 0);
	submenuSpeed->setValue(origSubmenuSpeed);
	//
	origGradientStyle = s.readEntry("/sofkstyle/Settings/gradientStyle", "SoftGradient");
	gradientStyle->setCurrentItem(gradientItem(origGradientStyle));
	origAlternateSinking = s.readBoolEntry("/sofkstyle/Settings/alternateSunkenEffect", false);
	alternateSinking->setChecked(origAlternateSinking);
	origCustomOverHighlightColor = s.readBoolEntry("/sofkstyle/Settings/customOverHighlightColor", true);
	customOverHighlightColor->setChecked(origCustomOverHighlightColor);
	origOverHighlightColor = s.readEntry("/sofkstyle/Settings/overHighlightColor", "#00d000");
	overHighlightColor->setColor(origOverHighlightColor);
	//origMouseOverLabel = s.readBoolEntry("/sofkstyle/Settings/mouseOverLabel", true);
	//mouseOverLabel->setChecked(origMouseOverLabel);
	origProgressBarPattern = s.readEntry("/sofkstyle/Settings/progressBarPattern", "Arrows");
	progressBarPattern->setCurrentItem(patternItem(origProgressBarPattern));
	origFlatProgressBar = s.readBoolEntry("/sofkstyle/Settings/flatProgressBar", true);
	flatProgressBar->setChecked(origFlatProgressBar);
	origAnimProgressBar = s.readBoolEntry("/sofkstyle/Settings/animateProgressBar", true);
	animateProgressBar->setChecked(origAnimProgressBar);
	origMenuGroove = s.readBoolEntry("/sofkstyle/Settings/menuGroove", true);
	menuGroove->setChecked(origMenuGroove);
	origDrawsoftGroupBox = s.readBoolEntry("/sofkstyle/Settings/drawsoftGroupBox", true);
	drawsoftGroupBox->setChecked(origDrawsoftGroupBox);
	origTabStyle = s.readEntry("/sofkstyle/Settings/tabStyle", "SoftButton");
	tabStyle->setCurrentItem(tabStyleItem(origTabStyle));
	origDrawSolidSeparator = s.readBoolEntry("/sofkstyle/Settings/drawSolidSeparator", true);
	drawSolidSeparator->setChecked(origDrawSolidSeparator);
	
	connect(drawTriangularExpander, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(drawFocusRect, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawToolBarHandle, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawToolBarSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(scrollBarStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(centerTabs, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(tabWarnStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(submenuSpeed, SIGNAL( valueChanged(int) ), SLOT( updateChanged() ) );
	//
	connect(gradientStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(alternateSinking, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(customOverHighlightColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(overHighlightColor, SIGNAL( pressed() ), SLOT( updateChanged() ) );
	//connect(mouseOverLabel, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(progressBarPattern, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(flatProgressBar, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(animateProgressBar, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(menuGroove, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawsoftGroupBox, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(tabStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(drawSolidSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	if (gradientStyle->currentItem() == 1)
		alternateSinking->setEnabled(false);
	else
		alternateSinking->setEnabled(true);
	//
	if ( customOverHighlightColor->isChecked() )
		overHighlightColor->setEnabled(true);
	else
		overHighlightColor->setEnabled(false);
}

sofkStyleConfig::~sofkStyleConfig()
{
}


void sofkStyleConfig::save()
{
	QSettings s;

	s.writeEntry("/sofkstyle/Settings/drawTriangularExpander", drawTriangularExpander->isChecked());
	s.writeEntry("/sofkstyle/Settings/drawFocusRect", drawFocusRect->isChecked());
	s.writeEntry("/sofkstyle/Settings/drawToolBarHandle", drawToolBarHandle->isChecked());
	s.writeEntry("/sofkstyle/Settings/drawToolBarSeparator", drawToolBarSeparator->isChecked());
	s.writeEntry("/sofkstyle/Settings/scrollBarStyle", scrollBarType(scrollBarStyle->currentItem()));
	s.writeEntry("/sofkstyle/Settings/centerTabs", centerTabs->isChecked());
	s.writeEntry("/sofkstyle/Settings/tabWarningStyle", tabWarnType(tabWarnStyle->currentItem()));
	s.writeEntry("/sofkstyle/Settings/submenuSpeed", submenuSpeed->value());
	//
	s.writeEntry("/sofkstyle/Settings/gradientStyle", gradientType(gradientStyle->currentItem()));
	s.writeEntry("/sofkstyle/Settings/alternateSunkenEffect", alternateSinking->isChecked());
	s.writeEntry("/sofkstyle/Settings/customOverHighlightColor", customOverHighlightColor->isChecked());
	s.writeEntry("/sofkstyle/Settings/overHighlightColor", QColor(overHighlightColor->color()).name());
	//s.writeEntry("/sofkstyle/Settings/mouseOverLabel", mouseOverLabel->isChecked());
	s.writeEntry("/sofkstyle/Settings/progressBarPattern", patternType(progressBarPattern->currentItem()));
	s.writeEntry("/sofkstyle/Settings/flatProgressBar", flatProgressBar->isChecked());
	s.writeEntry("/sofkstyle/Settings/animateProgressBar", animateProgressBar->isChecked());
	s.writeEntry("/sofkstyle/Settings/menuGroove", menuGroove->isChecked());
	s.writeEntry("/sofkstyle/Settings/drawsoftGroupBox", drawsoftGroupBox->isChecked());
	s.writeEntry("/sofkstyle/Settings/tabStyle", tabStyleType(tabStyle->currentItem()));
	s.writeEntry("/sofkstyle/Settings/drawSolidSeparator", drawSolidSeparator->isChecked());
}

void sofkStyleConfig::defaults()
{
	drawTriangularExpander->setChecked(true);
 	drawFocusRect->setChecked(true);
	drawToolBarHandle->setChecked(true);
	drawToolBarSeparator->setChecked(false);
	scrollBarStyle->setCurrentItem(2);
	centerTabs->setChecked(false);
	tabWarnStyle->setCurrentItem(0);
	submenuSpeed->setValue(0);
	//
	gradientStyle->setCurrentItem(0);
	alternateSinking->setChecked(false);
	customOverHighlightColor->setChecked(true);
	overHighlightColor->setColor("#00d000");
	//mouseOverLabel->setChecked(true);
	progressBarPattern->setCurrentItem(0);
	flatProgressBar->setChecked(false);
	animateProgressBar->setChecked(true);
	menuGroove->setChecked(true);
	drawsoftGroupBox->setChecked(true);
	tabStyle->setCurrentItem(0);
	drawSolidSeparator->setChecked(false);
}

void sofkStyleConfig::updateChanged()
{
	if (gradientStyle->currentItem() == 1)
		alternateSinking->setEnabled(false);
	else
		alternateSinking->setEnabled(true);
	//
	if ( customOverHighlightColor->isChecked() )
		overHighlightColor->setEnabled(true);
	else
		overHighlightColor->setEnabled(false);

	if ( (drawTriangularExpander->isChecked() != origDrawTriangularExpander) 
	|| (drawFocusRect->isChecked() != origDrawFocusRect) 
	|| (drawToolBarHandle->isChecked() != origDrawToolBarHandle) 
	|| (drawToolBarSeparator->isChecked() != origDrawToolBarSeparator) 
	|| (scrollBarStyle->currentText() != origScrollBarStyle) 
	|| (centerTabs->isChecked() != origCenterTabs) 
	|| (tabWarnStyle->currentText() != origTabWarnStyle) 
	|| (submenuSpeed->value() != origSubmenuSpeed) 
	//
	|| (gradientStyle->currentText() != origGradientStyle) 
	|| (alternateSinking->isChecked() != origAlternateSinking) 
	|| (customOverHighlightColor->isChecked() != origCustomOverHighlightColor) 
	|| (overHighlightColor->color() != origOverHighlightColor) 
	//|| (mouseOverLabel->isChecked() != origMouseOverLabel) 
	|| (progressBarPattern->currentText() != origProgressBarPattern) 
	|| (flatProgressBar->isChecked() != origFlatProgressBar) 
	|| (animateProgressBar->isChecked() != origAnimProgressBar) 
	|| (menuGroove->isChecked() != origMenuGroove) 
	|| (drawsoftGroupBox->isChecked() != origDrawsoftGroupBox) 
	|| (tabStyle->currentText() != origTabStyle) 
	|| (drawSolidSeparator->isChecked() != origDrawSolidSeparator) ) 
		emit changed(true);
	else
		emit changed(false);
}

// Scrollbar types
QString sofkStyleConfig::scrollBarType( int listnr )
{
	switch (listnr)
	{
		case 0: return QString("WindowsStyleScrollBar");
		case 1: return QString("PlatinumStyleScrollBar");
		case 2: return QString("ThreeButtonScrollBar");
		case 3: return QString("NextStyleScrollBar");
		case 4: return QString("ArrowlessScrollBar");
		default: return QString("ThreeButtonScrollBar");
	}
}

int sofkStyleConfig::scrollBarItem( QString kSBType )
{
    if( !strcmp(kSBType,"WindowsStyleScrollBar") )
        return 0;
    else if( !strcmp(kSBType,"PlatinumStyleScrollBar") )
        return 1;
    else if( !strcmp(kSBType,"NextStyleScrollBar") )
        return 3;
    else if( !strcmp(kSBType,"ArrowlessScrollBar") )
        return 4;
    else
        return 2;
}

// Scrollbar types
QString sofkStyleConfig::tabWarnType( int listnr )
{
	switch (listnr)
	{
		case 0: return QString("Deactivated");
		case 1: return QString("BoldText");
		case 2: return QString("ItalicText");
		case 3: return QString("AppDefault");
		default: return QString("Deactivated");
	}
}

int sofkStyleConfig::tabWarnItem( QString tbwnType )
{
    if( !strcmp(tbwnType,"Deactivated") )
        return 0;
    else if( !strcmp(tbwnType,"BoldText") )
        return 1;
    else if( !strcmp(tbwnType,"ItalicText") )
        return 2;
    else if( !strcmp(tbwnType,"AppDefault") )
        return 3;
    else
        return 0;
}

// Gradient types
QString sofkStyleConfig::gradientType( int listnr )
{
	switch (listnr)
	{
		case 1: return QString("FlatGradient");
		case 2: return QString("SoftGradient");
		case 3: return QString("HardGradient");
		default: return QString("RegularGradient");
	}
}

int sofkStyleConfig::gradientItem( QString grdType )
{
    if (! strcmp(grdType,"FlatGradient"))
        return 1;
    else if (! strcmp(grdType,"SoftGradient"))
        return 2;
    else if (! strcmp(grdType,"HardGradient"))
        return 3;
    else
        return 0;
}

// Pattern types
QString sofkStyleConfig::patternType( int listnr )
{
	switch (listnr)
	{
		case 1: return QString("CandyBar");
		case 2: return QString("Checker");
		case 3: return QString("Waves");
		default: return QString("Arrows");
	}
}

int sofkStyleConfig::patternItem( QString pttrType )
{
    if (! strcmp(pttrType,"CandyBar"))
        return 1;
    else if (! strcmp(pttrType,"Checker"))
        return 2;
    else if (! strcmp(pttrType,"Waves"))
        return 3;
    else
        return 0;
}

// Tab style types
QString sofkStyleConfig::tabStyleType( int listnr )
{
	switch (listnr)
	{
		case 1: return QString("softButton");
		case 2: return QString("HighlightedGradient");
		case 3: return QString("softGradient");
		case 4: return QString("Flat");
		default: return QString("HighlightedButton");
	}
}

int sofkStyleConfig::tabStyleItem( QString tbstType )
{
    if (! strcmp(tbstType,"softButton"))
        return 1;
    else if (! strcmp(tbstType,"HighlightedGradient"))
        return 2;
    else if (! strcmp(tbstType,"softGradient"))
        return 3;
    else if (! strcmp(tbstType,"Flat"))
        return 4;
    else
        return 0;
}

#include "sofkconf.moc"
